/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.sample.internal

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.kakao.sdk.partner.model.KakaoPhase
import com.kakao.sdk.partner.sample.databinding.ItemPhaseBinding
import io.reactivex.subjects.PublishSubject

class PhaseAdapter : RecyclerView.Adapter<PhaseViewholder>() {

    private val phases = KakaoPhase.values()
    private val phaseSubject = PublishSubject.create<KakaoPhase>()
    val phaseObservable = phaseSubject.hide()

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): PhaseViewholder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = ItemPhaseBinding.inflate(inflater, parent, false)
        return PhaseViewholder(binding)

    }

    override fun getItemCount(): Int = phases.size

    override fun onBindViewHolder(holder: PhaseViewholder, position: Int) {
        holder.bind(phases[position], phaseSubject)
    }
}

class PhaseViewholder(private val binding: ItemPhaseBinding) :
    RecyclerView.ViewHolder(binding.root) {
    fun bind(phase: KakaoPhase, subject: PublishSubject<KakaoPhase>) {
        binding.phase = phase
        binding.root.setOnClickListener {
            subject.onNext(phase)
        }
        binding.executePendingBindings()
    }
}